Main API
========

The primary interface.

.. nice-toc::

   global
      Constants and global variables used throughout Yuio.

   io
      Interacting with users.

   parse
      Parsing user input.

   ty
      Annotated types for easier parser construction.

   app
      Building CLI applications.

   config
      Working with configs.

   exec
      Executing sub-processes.

   git
      Querying GIT status.

   secret
      Working with sensitive data.

   dbg
      Automated environment collection for bug reports.
